mchammer.StepResult
===================

.. currentmodule:: mchammer

.. autoclass:: StepResult
   :members:
   :inherited-members:
   :undoc-members:
   :show-inheritance:


   
   
   .. rubric:: Methods

   .. autosummary::
      :nosignatures:
   
      ~StepResult.get_properties
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~StepResult.step
      ~StepResult.position_matrix
      ~StepResult.max_bond_distance
      ~StepResult.log
   
   